@@ -10,7 +10,7 @@ from fil3s import Files, Formats
 # functions.
 def __get_operating_system__():
 	os = platform.system().lower()
-	if os in ["darwin"]: return "osx"
+	if os in ["darwin"]: return "macos"
 	elif os in ["linux"]: return "linux"
 	else: raise ValueError(f"Unsupported operating system: [{os}].")
 def __get_source_path__(package_name, back=1):
@@ -73,7 +73,7 @@ GROUP = "root"
 HOME_BASE = "/home/"
 HOME = f"/home/{os.environ.get('USER')}/"
 MEDIA = f"/media/{os.environ.get('USER')}/"
-if OS in ["osx"]: 
+if OS in ["macos"]: 
 	HOME_BASE = "/Users/"
 	HOME = f"/Users/{os.environ.get('USER')}/"
 	MEDIA = f"/Volumes/"
