@@ -6,6 +6,7 @@ from r3sponse.classes.config import *
 from r3sponse.classes import utils
 from r3sponse.classes.utils import color, symbol
 from django.http import JsonResponse
+import json as pypi_json
 
 # the manager class.
 class R3sponse(object):
@@ -249,7 +250,6 @@ class R3sponse(object):
 
 		#
 
-
 	# a response object.
 	def serialize(self, response={}):
 		if isinstance(response, str):
@@ -297,12 +297,24 @@ class R3sponse(object):
 	}):
 		return self.response(self.serialize(response))
 	class ResponseObject(object):
-		def __init__(self, attributes={
-			"success":False,
-			"message":None,
-			"error":None,
-		}):
-			self.assign(attributes)
+		def __init__(self, 
+			# the response attributes.
+			attributes={
+				"success":False,
+				"message":None,
+				"error":None,
+			},
+			# import a dumped json response (str) (ignores attributes).
+			json=None,
+		):
+			if isinstance(json, str):
+				self.assign(pypi_json.loads(Formats.String(json).slice_dict()))
+			elif isinstance(json, dict):
+				self.assign(json)
+			elif json != None:
+				raise ValueError("Invalid usage, the r3sponse.ResponseObject json parameter must be str / dict format.")
+			else:
+				self.assign(attributes)
 		# iterate over self keys & variables.
 		def items(self):
 			return vars(self).items()
@@ -366,6 +378,16 @@ class R3sponse(object):
 				del self[i]
 				#except: a=1
 			return self
+		# crash the error message.
+		def crash(self, error="ValueError", traceback=True, json=False):
+			if json:
+				r3sponse.log(error=self["error"], json=json)
+				sys.exit(1)
+			else:
+				if not traceback:
+					sys.tracebacklimit = -1 ; sys.traceback_limit = -1
+				if error.lower() in ["valueerror"]: raise Exception(self["error"])
+				else: raise Exception(self["error"])
 		# count items.
 		def __len__(self):
 			return len(self.keys())
